summaryrefslogtreecommitdiffstats
path: root/sys/vm/vm.h
diff options
context:
space:
mode:
Diffstat (limited to 'sys/vm/vm.h')
-rw-r--r--sys/vm/vm.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/sys/vm/vm.h b/sys/vm/vm.h
index 832c335..9159e93 100644
--- a/sys/vm/vm.h
+++ b/sys/vm/vm.h
@@ -64,10 +64,10 @@
#include <machine/vm.h>
/*
* The exact set of cache control codes is machine dependent. However, every
* machine is required to define VM_CACHE_DEFAULT.
*/
-typedef char vm_cache_mode_t; /* cache control codes */
+typedef char vm_memattr_t; /* memory attribute codes */
typedef char vm_inherit_t; /* inheritance codes */
OpenPOWER on IntegriCloud
@@ -64,10 +64,10 @@
#include <machine/vm.h>
/*
- * The exact set of cache control codes is machine dependent. However, every
- * machine is required to define VM_CACHE_DEFAULT.
+ * The exact set of memory attributes is machine dependent. However, every
+ * machine is required to define VM_MEMATTR_DEFAULT.
*/